@@ -2,10 +2,11 @@ import os
 import sys
 from typing import Optional
 
+from deltachat import Account
+
 from .bot import DeltaBot
 from .parser import MyArgumentParser, get_base_parser
 from .plugins import get_global_plugin_manager
-from .utils import BotAccount
 
 
 def main(argv=None) -> None:
@@ -32,6 +33,6 @@ def make_bot_from_args(args, plugin_manager, account=None) -> Optional[DeltaBot]
     logger = plugin_manager.hook.deltabot_get_logger(args=args)
     if account is None:
         db_path = os.path.join(args.basedir, "account.db")
-        account = BotAccount(db_path, f"simplebot/{sys.platform}", logger)
+        account = Account(db_path)
 
     return DeltaBot(account, logger, plugin_manager=plugin_manager, args=args)
